@@ -596,7 +596,7 @@ class GitlabContainerRunner(
                 ec2type: typing.Optional[builtins.str] = None,
                 gitlab_runner_image: typing.Optional[builtins.str] = None,
                 gitlaburl: typing.Optional[builtins.str] = None,
-                instance_interruption_behavior: typing.Optional["InstanceInterruptionBehavior"] = None,
+                instance_interruption_behavior: typing.Optional[InstanceInterruptionBehavior] = None,
                 key_name: typing.Optional[builtins.str] = None,
                 selfvpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
                 spot_fleet: typing.Optional[builtins.bool] = None,
@@ -650,7 +650,7 @@ class GitlabContainerRunner(
         '''
         if __debug__:
             def stub(
-                props: typing.Union["GitlabContainerRunnerProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[GitlabContainerRunnerProps, typing.Dict[str, typing.Any]],
                 bucket_name: builtins.str,
             ) -> None:
                 ...
@@ -812,7 +812,7 @@ class GitlabContainerRunnerProps:
                 ec2type: typing.Optional[builtins.str] = None,
                 gitlab_runner_image: typing.Optional[builtins.str] = None,
                 gitlaburl: typing.Optional[builtins.str] = None,
-                instance_interruption_behavior: typing.Optional["InstanceInterruptionBehavior"] = None,
+                instance_interruption_behavior: typing.Optional[InstanceInterruptionBehavior] = None,
                 key_name: typing.Optional[builtins.str] = None,
                 selfvpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
                 spot_fleet: typing.Optional[builtins.bool] = None,
